@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 
     info->setHtml(
         "<b>"+ tr("YouTube%1 Browser for SMPlayer").arg(QChar(0x2122)) +"</b>"
-        "<p>&copy; 2012 Ricardo Villalba &lt;rvm@users.sourceforge.net&gt;" + 
+        "<p>&copy; 2012-2013 Ricardo Villalba &lt;rvm@users.sourceforge.net&gt;" + 
         "<br>" + tr("Based on UMPlayer") + " &copy; 2010 Ori Rejwan" 
         "<p><b>" +
         tr("Version: %1").arg(smtubeVersion()) + "</b>"
@@ -41,7 +41,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
         "<br>" +
         tr("Compiled with Qt %1 (using %2)").arg(QT_VERSION_STR).arg(qVersion()) + 
         "<p>" + 
-        tr("Visit our web for updates:") +"<br>"+ link("http://smplayer.sf.net")
+        tr("Visit our web for updates:") +"<br>"+ link("http://www.smtube.org")
     );
 
     license->setHtml(
@@ -59,6 +59,7 @@ About::About(QWidget * parent, Qt::WindowFlags f)
 
 	translators->setHtml( getTranslators() );
 
+
 	// Copy the background color ("window") of the tab widget to the "base" color of the qtextbrowsers
 	// Problem, it doesn't work with some styles, so first we change the "window" color of the tab widgets.
 	info_tab->setAutoFillBackground(true);
@@ -99,6 +100,23 @@ QString About::getTranslators() {
          trad(tr("Portuguese"), QString::fromUtf8("Sérgio Marques <smarquespt@gmail.com>")) +
          trad(tr("Hungarian"), "Gojko <m.gojko.71@gmail.com>") +
          trad(tr("Polish"), "Adam <ad56@poczta.fm>") +
+         trad(tr("Galician"), QString::fromUtf8("Adrián Chaves Fernández <adriyetichaves@gmail.com>")) +
+         trad(tr("Greek"), "dglent") +
+         trad(tr("Hebrew"), "Genghis Khan <genghiskhan@gmx.ca>") +
+         trad(tr("Portuguese (Brazil)"), QString::fromUtf8("Maico Sertório <maico.sertorio@gmail.com>")) +
+         trad(tr("Ukrainian"), "zubr139 (transifex)") +
+         trad(tr("Norwegian Nynorsk"), "bjorni (transifex)") +
+         trad(tr("Czech"), QString::fromUtf8("Petr Šimáček (transifex)")) +
+         trad(tr("Malay"), "abuyop (transifex)") +
+         trad(tr("Swedish"), QStringList() << "XC (transifex)" << "Andreas Gustafsson (transifex)") +
+         trad(tr("Turkish"), QStringList() << "Emre FIRAT (transifex)" << QString::fromUtf8("Hasan Akgöz (transifex)")) +
+         trad(tr("Finnish"), QString::fromUtf8("Jiri Grönroos (transifex)")) +
+         trad(tr("Georgian"), "George Machitidze (transifex)") +
+         trad(tr("Serbian"), QStringList() << QString::fromUtf8("Mladen Pejaković (transifex)") << "miroslav (transifex)") +
+         trad(tr("Croatian"), "gogo (transifex)") +
+         trad(tr("Bulgarian"), "Ivailo Monev (transifex)") +
+         trad(tr("Vietnamese"), QStringList() << "Phan Anh (transifex)" << "Biz Over (transifex)" << "Thu Thao Nguyen Ngoc (transifex)") +
+         trad(tr("Indonesian"), "Mohamad Hasan Al Banna (transifex)") +
          "");
 }
 
