@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,15 +34,22 @@ public:
 public slots:
     void setRecordingDirectory( const QString & folder );
     void setRecordingQuality( int quality );
-    void setRecordingFormat( int format );
+    void setPlaybackQuality( int quality );
     void setPlayerNames(QStringList names);
     void setPlayer(QString name);
+    void setRegion(const QString & region);
+    void setPeriod(const QString & period);
 
 public:
     QString recordingDirectory();
     int recordingQuality();
-    int recordingFormat();
+    int playbackQuality();
     QString player();
+    QString region();
+    QString period();
+
+protected slots:
+    void playerChanged(int);
 };
 
 #endif
