@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -37,9 +37,10 @@
 #include <QLabel>
 #include <QMenu>
 #include <QMessageBox>
+#include <QSettings>
 #include "recordingdialog.h"
 #include "downloadfile.h"
-#include "retrievevideourl.h"
+#include "rvu.h"
 /* #include "helper.h" */
 #include "myborder.h"
 
@@ -190,12 +191,13 @@ QSize RecordingDelegate::sizeHint(const QStyleOptionViewItem &option, const QMod
         return QSize(width, 50);
 }
 
-RecordingDialog::RecordingDialog(QWidget *parent) :
+RecordingDialog::RecordingDialog(QWidget *parent, QSettings * s) :
     QWidget(parent), pressedItemLeftButton(0), pressedItemRightButton(0)
 {
+    settings = s;
+
     recordings_directory = "/tmp/";
-    recording_quality = 37;
-    recording_format = 0;
+    recording_quality = RetrieveYoutubeUrl::MP4_720p;
 
     setWindowIcon( QPixmap(":/icons/logo.png") );
     setWindowTitle(tr("Recordings"));
@@ -248,37 +250,17 @@ RecordingDialog::~RecordingDialog()
 void RecordingDialog::downloadVideoId(QString videoId, QString title, double)
 {
     RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
-    connect(rvu, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), this, SLOT(recordVideo(QMap<int,QString>,QString,QString)));
-    connect(rvu, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), rvu, SLOT(deleteLater()));
+    rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) recording_quality);
+    connect(rvu, SIGNAL(signatureNotFound(const QString &)), this, SIGNAL(signatureNotFound(const QString &)));
+    connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)), this, SLOT(recordVideo(const QString &,QString,QString)));
+    connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)), rvu, SLOT(deleteLater()));
     rvu->fetchYTVideoPage(videoId, title);
 
     if(!isVisible()) show();
 }
 
-void RecordingDialog::recordVideo(QMap<int, QString> qualityMap, QString title, QString id)
+void RecordingDialog::recordVideo(const QString & url, QString title, QString id)
 {
-    QString url;
-    switch(recording_quality)
-    {
-    case RetrieveVideoUrl::FullHD:
-        url = qualityMap.value(RetrieveVideoUrl::FullHD, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::HD:
-        url = qualityMap.value(RetrieveVideoUrl::HD, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::Normal:
-        url = qualityMap.value(RetrieveVideoUrl::Normal, QString());
-        break;
-    case RetrieveVideoUrl::NormalFlv:
-        url = qualityMap.value(RetrieveVideoUrl::NormalFlv, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::BelowNormalFlv:
-        url = qualityMap.value(RetrieveVideoUrl::BelowNormalFlv, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::LowFlv:
-        url = qualityMap.value(RetrieveVideoUrl::LowFlv, QString());
-        break;
-    }
     if(url.isNull())
     {
         QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
@@ -289,13 +271,36 @@ void RecordingDialog::recordVideo(QMap<int, QString> qualityMap, QString title,
 
 void RecordingDialog::download(QString url, QString title, QString id, double duration)
 {
-    QUrl qurl(url);    
+    QUrl qurl(url);
     QListWidgetItem* item = new QListWidgetItem(0, QListWidgetItem::UserType + 1);
     downloadList->insertItem(0, item);
     DownloadData* dd = new DownloadData;
     dd->downloadState = DownloadData::Progressing;
     dd->videoId = id;
-    QFile* file = new QFile(getUniqueFileName(title + (recording_format == 0 ? ".mp4" : ".flv")));
+
+    int itag = recording_quality;
+    QRegExp rx("itag=(\\d+)");
+    if (rx.indexIn(url) != -1) {
+        itag = rx.cap(1).toInt();
+        //qDebug("itag: %d", itag);
+    }
+
+    QString ext = ".mp4";
+    switch (itag) {
+        case RetrieveYoutubeUrl::FLV_240p:
+        case RetrieveYoutubeUrl::FLV_360p:
+        case RetrieveYoutubeUrl::FLV_480p:
+            ext = ".flv";
+            break;
+        case RetrieveYoutubeUrl::WEBM_360p:
+        case RetrieveYoutubeUrl::WEBM_480p:
+        case RetrieveYoutubeUrl::WEBM_720p:
+        case RetrieveYoutubeUrl::WEBM_1080p:
+            ext = ".webm";
+            break;
+    }
+
+    QFile* file = new QFile(getUniqueFileName(title + ext));
     dd->title = QFileInfo(*file).fileName();
     dd->filePath = QFileInfo(*file).absoluteFilePath();
     dd->videoDuration = (int)duration;
@@ -303,6 +308,7 @@ void RecordingDialog::download(QString url, QString title, QString id, double du
     dd->completionTime = QDateTime::currentDateTime();
     item->setData(DownloadDataRole, QVariant::fromValue(dd));
     item->setData(emitDataChangedRole, true);
+
     DownloadFile* dfile = new DownloadFile(url, file, this);
     file->setParent(dfile);    
     itemDownloadMap[dfile] = item;    
@@ -625,7 +631,9 @@ void RecordingDialog::retryDownload(QListWidgetItem *item)
     dd->downloadProgressPercent = 0;
     item->setData(emitDataChangedRole, !item->data(emitDataChangedRole).toBool());
     RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
-    connect(rvu, SIGNAL(gotUrls(QMap<int,QString>,QString, QString)), this, SLOT(urlToDownload(QMap<int,QString>,QString)));
+    rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) recording_quality);
+    connect(rvu, SIGNAL(signatureNotFound(const QString &)), this, SIGNAL(signatureNotFound(const QString &)));
+    connect(rvu, SIGNAL(gotPreferredUrl(const QString &,QString, QString)), this, SLOT(urlToDownload(const QString &,QString)));
     connect(rvu, SIGNAL(errorOcurred(QString,int)), this, SLOT(fetchUrlError(QString,int)));
     rvu->fetchYTVideoPage(dd->videoId, dd->title);
     itemRVUMap[rvu] = item;
@@ -650,30 +658,8 @@ void RecordingDialog::playDownload(QListWidgetItem *item)
     emit playFile(dd->filePath);
 }
 
-void RecordingDialog::urlToDownload(QMap<int, QString> qualityMap, QString title)
+void RecordingDialog::urlToDownload(const QString & url, QString title)
 {
-    QString url;
-    switch(recording_quality)
-    {
-    case RetrieveVideoUrl::FullHD:
-        url = qualityMap.value(RetrieveVideoUrl::FullHD, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::HD:
-        url = qualityMap.value(RetrieveVideoUrl::HD, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::Normal:
-        url = qualityMap.value(RetrieveVideoUrl::Normal, QString());
-        break;
-    case RetrieveVideoUrl::NormalFlv:
-        url = qualityMap.value(RetrieveVideoUrl::NormalFlv, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::BelowNormalFlv:
-        url = qualityMap.value(RetrieveVideoUrl::BelowNormalFlv, QString());
-        if(!url.isNull()) break;
-    case RetrieveVideoUrl::LowFlv:
-        url = qualityMap.value(RetrieveVideoUrl::LowFlv, QString());
-        break;
-    }
     if(url.isNull())
     {
         QMessageBox::warning(0, tr("Recording failed"), tr("There was an error in retrieving the download URL."));
@@ -800,15 +786,27 @@ void RecordingDialog::saveList()
         }
         itemList.append(ddMap);
     }
+
+    if (settings) {
+        settings->beginGroup("recording");
+        settings->setValue("history", itemList);
+        settings->endGroup();
+    }
     /* pref->downloadHistory = itemList; */
 }
 
 void RecordingDialog::loadList()
 {
-    /*
-    for(int i=0; i < pref->downloadHistory.count(); ++i)
+    if (settings==0) return;
+
+    QList<QVariant> downloadHistory;
+    settings->beginGroup("recording");
+    downloadHistory = settings->value("history").toList();
+    settings->endGroup();
+
+    for(int i=0; i < downloadHistory.count(); ++i)
     {
-        QVariantMap ddMap = pref->downloadHistory.value(i).toMap();
+        QVariantMap ddMap = downloadHistory.value(i).toMap();
         QListWidgetItem* item = new QListWidgetItem(0, QListWidgetItem::UserType + 1);
         downloadList->insertItem(0, item);
         DownloadData* dd = new DownloadData;
@@ -822,7 +820,6 @@ void RecordingDialog::loadList()
         item->setData(DownloadDataRole, QVariant::fromValue(dd));
         item->setData(emitDataChangedRole, true);
     }
-    */
 }
 
 #include "moc_recordingdialog.cpp"
