@@ -1,5 +1,5 @@
 /*  smtube, a small youtube browser.
-    Copyright (C) 2012 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2012-2013 Ricardo Villalba <rvm@users.sourceforge.net>
     Copyright (C) 2010 Ori Rejwan
 
     This program is free software; you can redistribute it and/or modify
@@ -40,13 +40,18 @@
 #include "yttabbar.h"
 #include "ytdelegate.h"
 #include "ytdataapi.h"
-#include "retrievevideourl.h"
+#include "rvu.h"
 #include "myborder.h"
 #include "searchbox.h"
 #include "recordingdialog.h"
 #include "configdialog.h"
 #include "about.h"
 
+#ifdef YT_USE_SCRIPT
+#include "ytsig.h"
+#include "codedownloader.h"
+#endif
+
 #define PAGE_RESULT_COUNT 25
 
 OverlayWidget::OverlayWidget(QWidget* parent) : QWidget(parent)
@@ -204,6 +209,7 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     QWidget(parent), overlayVisible(false)
 {
     set = settings;
+    playback_quality = RetrieveYoutubeUrl::MP4_720p;
 
     setWindowIcon( QPixmap(":/icons/logo.png") );
     setAutoFillBackground(true);
@@ -211,13 +217,12 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     tabBar = new YTTabBar(this);
     connect(tabBar, SIGNAL(currentChanged(int)), this, SLOT(gotCurrentTab(int)));
     overlay = new OverlayWidget(this);
-    videoList = new QListWidget(this);
+    videoList = new SmoothListWidget(this);
     pixmap_loader = new PixmapLoader;
 
-    recording_dialog = new RecordingDialog;
+    recording_dialog = new RecordingDialog(0, settings);
     recording_dialog->setRecordingsDirectory("");
-    recording_dialog->setRecordingQuality(HD);
-    recording_dialog->setRecordingFormat(0);
+    recording_dialog->setRecordingQuality(RetrieveYoutubeUrl::MP4_720p);
 
     MyBorder* border = new MyBorder(this);
     border ->setBGColor(palette().color(backgroundRole()));
@@ -241,6 +246,12 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     prevButton->setShortcut(QKeySequence("Alt+P"));
     prevButton->adjustSize();
     prevButton->setFixedWidth(prevButton->width());
+
+    if (!qApp->isLeftToRight()) {
+        nextButton->setIcon(QPixmap::fromImage(QPixmap(":/icons/next.png").toImage().mirrored(true, false)));
+        prevButton->setIcon(QPixmap::fromImage(QPixmap(":/icons/previous.png").toImage().mirrored(true, false)));
+    }
+
     searchBox = new SearchBox(this);
     connect(searchBox, SIGNAL(search(QString)), this, SLOT(setSearchTerm(QString)));    
     connect(nextButton, SIGNAL(clicked()), this, SLOT(nextClicked()));
@@ -259,8 +270,15 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     infoButton->setShortcut(QKeySequence("Alt+I"));
     connect(infoButton, SIGNAL(clicked()), this, SLOT(showAboutDialog()));
 
+    recordingButton = new QToolButton(this);
+    recordingButton->setIcon(QPixmap(":/icons/recordings.png"));
+    recordingButton->setToolTip(tr("Show recordings"));
+    recordingButton->setShortcut(QKeySequence("Alt+R"));
+    connect(recordingButton, SIGNAL(clicked()), recording_dialog, SLOT(show()));
+
     QHBoxLayout* hbox = new QHBoxLayout;
     hbox->addWidget(searchBox);
+    hbox->addWidget(recordingButton);
     hbox->addWidget(configButton);
     hbox->addWidget(infoButton);
 
@@ -287,6 +305,9 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
     connect(videoList, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
 
     connect(recording_dialog, SIGNAL(playFile(QString)), this, SLOT(playVideo(QString)));
+    connect(recording_dialog, SIGNAL(signatureNotFound(const QString &)),
+            this, SLOT(showErrorSignatureNotFound(const QString &)));
+
     /*
     connect(this, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), 
             this, SLOT(playYTUrl(QMap<int,QString>,QString, QString)));
@@ -299,11 +320,32 @@ YTDialog::YTDialog(QWidget *parent, QSettings * settings) :
 
     loadConfig();
 
+	move(0, 0);
+	resize(400, 500);
+	// Load position and size
+	if (set) {
+		set->beginGroup("main_window");
+		QPoint p = set->value("pos", pos()).toPoint();
+		QSize s = set->value("size", size()).toSize();
+		set->endGroup();
+		move(p);
+		resize(s);
+	}
+
     searchBox->setFocus();
 }
 
 YTDialog::~YTDialog() 
 {
+	// Save position and size
+	if (set) {
+		set->beginGroup("main_window");
+		set->setValue("pos", pos());
+		set->setValue("size", size());
+		set->endGroup();
+		set->sync();
+	}
+
     delete pixmap_loader;
     delete recording_dialog; 
 }
@@ -313,7 +355,8 @@ void YTDialog::setLoadingOverlay(bool enable)
     overlayVisible = enable;
     if(enable)
     {
-        overlay->resize(size());
+        overlay->move(videoList->pos());
+        overlay->resize(videoList->size());
         overlay->setText(QString());
         overlay->show();
     }
@@ -327,7 +370,8 @@ void YTDialog::resizeEvent(QResizeEvent* r)
 {
     if(overlayVisible)
     {
-        overlay->resize(r->size());
+        overlay->move(videoList->pos());
+        overlay->resize(videoList->size());
     }
 }
 
@@ -378,7 +422,7 @@ void YTDialog::setMode(Mode mode)
         searchTerm = QString();
         searchBox->setText(searchTerm);
         addTab(Popular);
-        addTab(ViewedButton);
+        addTab(Music);
         addTab(Rated);        
     }
     else if(mode == Search)
@@ -412,9 +456,9 @@ void YTDialog::addTab(Tabs tab)
     {
         index = tabBar->addTab(tr("Most Popular"));
     }
-    else if(tab == ViewedButton)
+    else if(tab == Music)
     {
-        index = tabBar->addTab(tr("Most Viewed"));
+        index = tabBar->addTab(tr("Music Top Rated"));
     }
     else if(tab == Rated)
     {
@@ -431,7 +475,7 @@ void YTDialog::gotCurrentTab(int index)
     {
     case Popular: setWindowTitle(tr("Most popular videos on YouTube%1").arg(QChar(0x2122)));break;
     case Rated: setWindowTitle(tr("Most rated videos on YouTube%1").arg(QChar(0x2122)));break;
-    case ViewedButton: setWindowTitle(tr("Most viewed videos on YouTube%1").arg(QChar(0x2122)));break;
+    case Music: setWindowTitle(tr("Most rated music videos this week on YouTube%1").arg(QChar(0x2122)));break;
     case Relevant :
     case Recent :
     case Viewed : setWindowTitle(tr("YouTube%2 results for \"%1\"").arg(searchTerm).arg(QChar(0x2122)));break;
@@ -448,7 +492,7 @@ void YTDialog::gotCurrentTab(int index)
         {
         case Popular: resultForTab[api->getMost(Popular)] = Popular; break;
         case Rated: resultForTab[api->getMost(Rated)]= Rated; break;
-        case ViewedButton: resultForTab[api->getMost(ViewedButton)]= ViewedButton; break;
+        case Music: resultForTab[api->getMost(Music)]= Music; break;
         case Relevant : resultForTab[api->getMost(Relevant, searchTerm)]= Relevant; break;
         case Recent : resultForTab[api->getMost(Recent, searchTerm)]= Recent; break;
         case Viewed : resultForTab[api->getMost(Viewed, searchTerm)]= Viewed; break;
@@ -507,6 +551,7 @@ void YTDialog::updateNextPrevWidget()
             pendingPixmapQueue[id] = svi;
         }
         wItem->setData(0, qVariantFromValue(*it));
+        wItem->setToolTip(svi->header);
         ++it;
     }        
     if(thisPageNo < lastPageNo(tab))
@@ -625,8 +670,16 @@ void YTDialog::videoDblClicked(QListWidgetItem *item)
     SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
     if (!players.currentPlayer().directPlay()) {
         RetrieveVideoUrl* rvu = new RetrieveVideoUrl(this);
-        connect(rvu, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), this, SLOT(playYTUrl(QMap<int,QString>, QString, QString)) );
-        connect(rvu, SIGNAL(gotUrls(QMap<int,QString>, QString, QString)), rvu, SLOT(deleteLater()));
+        rvu->setPreferredQuality((RetrieveYoutubeUrl::Quality) playback_quality);
+        #ifdef YT_USE_SCRIPT
+        YTSig::setScriptFile(script_file);
+        #endif
+        connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)),
+                this, SLOT(playYTUrl(const QString &, QString, QString)));
+        connect(rvu, SIGNAL(signatureNotFound(const QString &)), 
+                this, SLOT(showErrorSignatureNotFound(const QString &)));
+        connect(rvu, SIGNAL(gotPreferredUrl(const QString &, QString, QString)),
+                rvu, SLOT(deleteLater()));
         rvu->fetchYTVideoPage( svi->videoid, svi->header );
     } else {
         QString video = "http://www.youtube.com/watch?v=" + svi->videoid;
@@ -667,6 +720,10 @@ void YTDialog::showContextMenu(QPoint point)
 
 void YTDialog::recordItem(QListWidgetItem *item)
 {
+    #ifdef YT_USE_SCRIPT
+    YTSig::setScriptFile(script_file);
+    #endif
+
     SingleVideoItem* svi = item->data(0).value<SingleVideoItem*>();
     recording_dialog->downloadVideoId(svi->videoid, svi->header, 0);
 }
@@ -678,21 +735,8 @@ void YTDialog::playVideo(QString file)
     QProcess::startDetached(exec, QStringList() << file);
 }
 
-void YTDialog::playYTUrl(const QMap<int, QString> &qualityMap, QString title, QString id)
+void YTDialog::playYTUrl(const QString & url, QString title, QString id)
 {
-    QString url;
-    switch( recording_dialog->recordingQuality() )
-    {
-    case YTDialog::FullHD:
-        url = qualityMap.value(YTDialog::FullHD, QString());
-        if(!url.isNull()) break;
-    case YTDialog::HD:
-        url = qualityMap.value(YTDialog::HD, QString());
-        if(!url.isNull()) break;
-    case YTDialog::Normal:
-        url = qualityMap.value(YTDialog::Normal, QString());
-    }
-
     qDebug("YTDialog::playYTUrl: title: '%s', url: '%s'", title.toUtf8().constData(), url.toUtf8().constData());
 
     QString exec = players.currentPlayer().executable();
@@ -727,6 +771,31 @@ void YTDialog::showErrorDialog(const QString & error)
     QMessageBox::warning(this, tr("Error"), error);
 }
 
+void YTDialog::showErrorSignatureNotFound(const QString & title) {
+	qDebug("YTDialog::showErrorSignatureNotFound: %s", title.toUtf8().constData());
+
+	QString t = title;
+	t.replace(" - YouTube", "");
+
+	#ifdef YT_USE_SCRIPT
+	static CodeDownloader * downloader = 0;
+	int ret = QMessageBox::question(this, tr("Problems with Youtube"),
+				tr("Unfortunately due to changes in Youtube, the video '%1' can't be played or recorded.").arg(t) + "<br><br>" +
+				tr("Do you want to update the Youtube code? This may fix the problem."),
+				QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes);
+	if (ret == QMessageBox::Yes) {
+		if (!downloader) downloader = new CodeDownloader(this);
+		downloader->saveAs(script_file);
+		downloader->show();
+		downloader->download(QUrl("http://updates.smplayer.info/ytcode.script"));
+	}
+	#else
+	QMessageBox::warning(this, tr("Problems with Youtube"),
+		tr("Unfortunately due to changes in Youtube, the video '%1' can't be played or recorded.").arg(t) + "<br><br>" +
+		tr("Maybe updating this application could fix the problem."));
+	#endif
+}
+
 void YTDialog::showAboutDialog() 
 {
     About d(this);
@@ -739,17 +808,29 @@ void YTDialog::showConfigDialog()
 
     ConfigDialog d(this);
     d.setRecordingDirectory(recording_dialog->recordingsDirectory());
-    d.setRecordingFormat(recording_dialog->recordingFormat());
     d.setRecordingQuality(recording_dialog->recordingQuality());
     d.setPlayerNames( players.availablePlayers() );
     d.setPlayer( players.currentPlayer().name() );
+    d.setPlaybackQuality( playback_quality );
+
+    QString period = api->period();
+    QString region = api->region();
+
+    d.setPeriod( period );
+    d.setRegion( region );
 
     if (d.exec() == QDialog::Accepted) {
         recording_dialog->setRecordingsDirectory(d.recordingDirectory());
-        recording_dialog->setRecordingFormat(d.recordingFormat());
         recording_dialog->setRecordingQuality(d.recordingQuality());
         players.setCurrent( players.findName( d.player() ) );
+        playback_quality = d.playbackQuality();
+        api->setPeriod( d.period() );
+        api->setRegion( d.region() );
         saveConfig();
+
+        if ((d.period() != period) || (d.region() != region)) {
+            setMode(YTDialog::Button); // Refresh list
+        }
     }
 }
 
@@ -759,9 +840,11 @@ void YTDialog::loadConfig()
     if (set) {
         set->beginGroup("general");
         recording_directory = set->value("recording_directory", recording_dialog->recordingsDirectory()).toString();
-        recording_dialog->setRecordingFormat(set->value("recording_format", recording_dialog->recordingFormat()).toInt());
-        recording_dialog->setRecordingQuality(set->value("recording_quality", recording_dialog->recordingQuality()).toInt());
+        recording_dialog->setRecordingQuality(set->value("record_quality", recording_dialog->recordingQuality()).toInt());
         players.setCurrent(set->value("player", players.current()).toInt());
+        api->setRegion(set->value("region", "US").toString());
+        api->setPeriod(set->value("period", "today").toString());
+        playback_quality = set->value("playback_quality", playback_quality).toInt();
         set->endGroup();
     }
 
@@ -796,9 +879,11 @@ void YTDialog::saveConfig()
     if (set) {
         set->beginGroup("general");
         set->setValue("recording_directory", recording_dialog->recordingsDirectory());
-        set->setValue("recording_format", recording_dialog->recordingFormat());
-        set->setValue("recording_quality", recording_dialog->recordingQuality());
+        set->setValue("record_quality", recording_dialog->recordingQuality());
         set->setValue("player", players.current());
+        set->setValue("region", api->region());
+        set->setValue("period", api->period());
+        set->setValue("playback_quality", playback_quality);
         set->endGroup();
         set->sync();
     }
